{% load static %}
{% block content_column_1 %}
			<div class="campl-column12 campl-main-content">
    			<div class="campl-content-container">
                    <h2>Some title</h2>
                    <p>some content</p>
				</div>
			</div>
{% endblock %}
{% block content_column_2 %}
{% endblock %}
{% block content_column_3 %}
{% endblock %}
{% block content_column_4 %}
{% endblock %}
{% block content_column_5 %}
{% endblock %}
{% block content_column_6 %}
{% endblock %}
{% block content_column_7 %}
{% endblock %}
{% block content_column_8 %}
{% endblock %}
{% block content_column_9 %}
{% endblock %}
{% block content_column_10 %}
{% endblock %}
{% block content_column_11 %}
{% endblock %}
{% block content_column_12 %}
{% endblock %}