 			<div class="campl-column10">				
                <div class="campl-content-container">
                    <h1 >{% block subtitle %}Subtitle of my Django app{% endblock %}</h1>
                </div>
            </div>
 			<div class="campl-column2">
                 <div class="campl-content-container campl-user_identity">
                 	{% block usercontrol %}
                    <p>
                        You are logged in as
                        <b>Helen Sargan</b>
                        <br />
                    <a title="Administer quick links and search filters for your institutions" href="/admin">Administer Search</a>
                    {% endblock %}
                    </p>
     			</div>
    		</div>