{% load static %}
{# campl puts some js in the footer of each page (for jquery / jquery ui stuff will break) #}
	<script type="text/javascript" src="{% static 'javascripts/libs/ios-orientationchange-fix.js' %}"></script>
  	<script type="text/javascript" src="{% static 'javascripts/libs/jquery-min.js' %}"></script>
	<script type="text/javascript" src="{% static 'javascripts/libs/modernizr.js' %}"></script>
  	<script type="text/javascript" src="{% static 'javascripts/apps-custom.js' %}"></script>