{% load static %}
{% block content_column_1 %}
		    <div class="campl-column2 campl-login-form">
    			<div class="campl-content-container">
<img src="{% static 'images/raven-logo.gif' %}" alt="" width="100" height="99" />
				</div>
			</div>
{% endblock %}
{% block content_column_2 %}
			<div class="campl-column10">
    			<div class="campl-content-container">
<p>This is a Django app themed with the Project Light for Django templates.</p>

<h2>h2 is used for headings</h2>

<p>So now you know.</p>
        	    </div>
        	</div>
{% endblock %}
{% block content_column_3 %}
{% endblock %}
{% block content_column_4 %}
{% endblock %}
{% block content_column_5 %}
{% endblock %}
{% block content_column_6 %}
{% endblock %}
{% block content_column_7 %}
{% endblock %}
{% block content_column_8 %}
{% endblock %}
{% block content_column_9 %}
{% endblock %}
{% block content_column_10 %}
{% endblock %}
{% block content_column_11 %}
{% endblock %}
{% block content_column_12 %}
{% endblock %}