		<div class="campl-row campl-local-footer">
			<div class="campl-wrap clearfix">
                <div class="campl-column3 campl-footer-navigation">
                </div>
                <div class="campl-column3 campl-footer-navigation">
                </div>
                <div class="campl-column3 campl-footer-navigation">
                    <div class="campl-content-container campl-navigation-list">
                        <h3 class="block-title"><a href="/about-this-site/connect-with-us" class="block-title-link">Connect with us</a></h3>
                        <ul>
                            <li>
		                        <a href="http://www.facebook.com/cambridge.university">Facebook</a></li>
	                        <li>
		                        <a href="http://www.flickr.com/photos/cambridgeuniversity">Flickr</a></li>
	                        <li>
		                        <a href="/video-and-audio/itunes-u">iTunes U</a></li>
	                        <li>
		                        <a href="http://www.linkedin.com/company/university-of-cambridge">Linked in</a></li>
	                        <li>
		                        <a href="https://www.twitter.com/cambridge_uni">Twitter</a></li>
	                        <li>
		                        <a href="https://www.youtube.com/cambridgeuniversity">YouTube</a></li>
                        </ul>
                    </div>
                    <!-- /.block -->
                </div>
                <div class="campl-column3 campl-footer-navigation last">
                    <div class="campl-content-container campl-navigation-list">
                        <h3 class="block-title"><a href="/about-this-site" class="block-title-link">About this site</a></h3>
                        <ul class="menu">
                            <li class="first leaf"><a href="/about-this-site/cookies" title="">Cookies</a></li>
                            <li class="last leaf"><a href="/about-this-site/privacy-policy" title="">Privacy policy</a></li>
                        </ul>
                    </div>
                    <!-- /.block -->
                </div>
            </div>
        </div>