	<div class="campl-row campl-global-footer">
		<div class="campl-wrap clearfix">
			<div class="campl-column3 campl-footer-navigation">
				<div class="campl-content-container campl-navigation-list">
					<p>&#169; {% now "Y" %} University of Cambridge</p>
				</div>
			</div>
			<div class="campl-column3 campl-footer-navigation">
				<div class="campl-content-container campl-navigation-list">
					<div class="link-list">
						<h3><a href="http://www.cam.ac.uk/study-at-cambridge">Study at Cambridge</a></h3> 
				</div>
				</div>
			</div>
			<div class="campl-column3 campl-footer-navigation">
				<div class="campl-content-container campl-navigation-list">
					<h3><a href="http://www.cam.ac.uk/about-the-university">About the University</a></h3> 
				</div>
			</div>
			<div class="campl-column3 campl-footer-navigation last">
				<div class="campl-content-container campl-navigation-list">
					<h3><a href="http://www.cam.ac.uk/research">Research at Cambridge</a></h3> 
				</div>
			</div>
		</div>	
	</div>