{% load static %}
	<div class="campl-row campl-global-header">
		<div class="campl-wrap clearfix">	
			<div class="campl-header-container campl-column10" id="global-header-controls">
				<a href="/" class="campl-main-logo">
					<img alt=""  src="{% static 'images/interface/main-logo-small.png' %}" />
				</a>
			</div>
{# TODO - this was in the template for apps but not for search. What is the purpose? #}			
{# <div class="campl-column2"> #}
{# </div> #}
		</div>		
	</div>	