{% load static %}
	<div class="campl-row campl-page-header global-page">
		<div class="campl-wrap clearfix">
			<div class="campl-column12">
				<div class="campl-content-container">
					{# Some sites (such as search) disable breadcrumbs completely. Override this block if you wish to do that. #} 
				    {% block all_breadcrumbs %}
					<div class="campl-breadcrumb" id="breadcrumb">
						<ul class="campl-unstyled-list campl-horizontal-navigation clearfix">
							<li class='first-child'>
								<a href="/" class="campl-home ir">Home</a>
							</li>
							{% block static_breadcrumbs %}
							{% comment %}
							    Hard-code as many of these static breadcrumbs as you like.
							    They'll be displayed for every page in your app, before the dynamic
							    breadcrumbs you supply from your view, if any.
							{% endcomment %}
							{# My parent organisation #}
							<li>
								<a href="http://www.cam.ac.uk/">University of Cambridge</a>
							</li>
							{# My app name #}
							<li>
								<a href="http://www.cam.ac.uk/about-the-university/">My Django app</a>
							</li>
							{% endblock %}
							{% comment %}
						        Application-specific breadcrumbs are handled by this little loop.
							    Pass a dictionary of any additional breadcrumbs as "breadcrumbs"
							    like:
							        breadcrumbs = {}
							        breadcrumbs[0] = dict(name='Page of my cool app', url='http://my.cool.app/page/')
							        breadcrumbs[1] = dict(name='Subpage of my cool app', url='http://my.cool.app/page/subthingy/')
							        ...
							        return render_to_response('campl.html', {'breadcrumbs':breadcrumbs, ...})
							{% endcomment %}
							{% for index, breadcrumb in breadcrumbs.items %}
							<li>
								<a href="{{ breadcrumb.url }}">{{ breadcrumb.name }}</a>
							</li>
							{% endfor %}
						</ul>
					</div>
<!-- 
					{# TODO check with IPG the logic for what to put here is correct #}
					<p class="campl-mobile-parent"><a href="{{ breadcrumbs.0.url }}"><span class="campl-back-btn campl-menu-indicator"></span>{{ breadcrumbs.0.name }}</a></p>
 -->
 					{% endblock %}
                    <p class="campl-page-title">{% block full_site_name %}A Django App for Project Light{% endblock %}</p>
                    {% block search_bar %}
                    <div class="campl-column6">
                        <form action="{% block search_action %}/web{% endblock %}" method="get" >
                            <fieldset>
                                <div class="campl-control-group">
                                    <label for="query" class="visuallyhidden" onfocus="used=true;">query</label>
                                    <div class="campl-search-input">
                                        <input type="text" id="query" name="query" size="40" value="" />
                                        <input class="campl-search-submit " type="image" src="{% static 'images/interface/btn-search-inpage.png' %}" />
                                    </div>  
                                </div>                           
                            </fieldset>
                        </form>
                    </div>
					{% endblock %}
				</div>
			</div>
		</div>
	</div>