		<div class="campl-row campl-local-footer campl-app-footer">
			<div class="campl-wrap clearfix">
				<div class="campl-column6 campl-footer-navigation">
					<p class="campl-app-footer-content">{% block blurb %}This Django app is provided and managed by <a href="http://www.cam.ac.uk">somebody in Cambridge (probably)</a>.{% endblock %}</p>
				</div>
				<div class="campl-column3 campl-footer-navigation">
					<div class="campl-content-container campl-navigation-list">
						{% block help %}<h3><a href="">Help</a></h3>{% endblock %}
					</div>
				</div>
				<div class="campl-column3 campl-footer-navigation last">
					<div class="campl-content-container campl-navigation-list">
						{% block policies %}<h3><a href="">Privacy &amp; cookie policy</a></h3>{% endblock %} 
					</div>
				</div>
			</div>	
		</div>