 			<div class="campl-column12">				
                <div class="campl-content-container">
                    <h1 >{% block subtitle %}Subtitle of my Django app{% endblock %}</h1>
                </div>
            </div>