.styleguide-notes .campl-wrap{width:50%}

.styleguide-notes img{padding:0 0 20px 0}

.styleguide-notes h1{line-height:40px}
.styleguide-notes h5{color:#999}
.styleguide-notes h4{clear:both}

.grid-border{border:1px solid #e4e4e4;background:#efefef}
.grid-border .grid-border{background:#fff}

.center-img{text-align:center;padding:10px}

.styleguide-menu{margin-top:20px}
.styleguide-menu li{margin-bottom:20px}

.styleguide-notes{background:#fff}
.styleguide-container{border:1px solid #e4e4e4;margin-bottom:40px}

@media only screen and (max-width: 1024px){
	.styleguide-notes .campl-wrap{width:100%}
}


@media print {
	.styleguide-notes .campl-wrap{width:100%}
}

.styleguide .campl-global-navigation{
	font-size:13px;
}