        <div class="campl-column12 campl-main-content">
		    {% block subtitle %}
			{% include 'campl-subtitle-simple.html' %}
    		{% endblock %}
    		{% block tabs %}
			{% include 'campl-tabs.html' %}
	        {% endblock %}
        </div>